==> ant-design-vue-2.0.0-rc.9.jar: META-INF/resources/webjars/ant-design-vue/2.0.0-rc.9/lib/date-picker/WeekPicker.d.ts <==
import moment from 'moment';
interface WeekPickerState {
    _open?: boolean;
    _value?: moment.Moment | null;
}
declare const _default: import("vue").DefineComponent<{
    placeholder: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    value: {
        type: import("vue").PropType<import("./props").PickerValue>;
    };
    defaultValue: {
        type: import("vue").PropType<import("./props").PickerValue>;
    };
    defaultPickerValue: {
        type: import("vue").PropType<import("./props").PickerValue>;
    };
    renderExtraFooter: import("vue-types").VueTypeValidableDef<any>;
    onChange: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    name: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    transitionName: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    inputPrefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    format: import("vue-types").VueTypeDef<any>;
    disabled: import("vue-types").VueTypeValidableDef<boolean>;
    allowClear: import("vue-types").VueTypeValidableDef<boolean>;
    suffixIcon: import("vue-types").VueTypeValidableDef<any>;
    popupStyle: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    };
    dropdownClassName: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    locale: import("vue-types").VueTypeValidableDef<any>;
    localeCode: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    size: import("vue-types").VueTypeDef<"default" | "small" | "large">;
    getCalendarContainer: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    open: import("vue-types").VueTypeValidableDef<boolean>;
    disabledDate: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    showToday: import("vue-types").VueTypeValidableDef<boolean>;
    dateRender: import("vue-types").VueTypeValidableDef<any>;
    pickerClass: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    pickerInputClass: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    timePicker: import("vue-types").VueTypeValidableDef<any>;
    autofocus: import("vue-types").VueTypeValidableDef<boolean>;
    tagPrefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    tabindex: import("vue-types").VueTypeDef<import("../_util/type").Key>;
    align: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    } & {
        default: () => {
            [key: string]: any;
        };
    };
    inputReadOnly: import("vue-types").VueTypeValidableDef<boolean>;
    valueFormat: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    onOpenChange: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    onFocus: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    onBlur: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    onMouseenter: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    onMouseleave: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
}, {
    configProvider: import("../config-provider").ConfigConsumerProps;
    prevState: WeekPickerState;
    input: any;
    sPrefixCls: any;
}, WeekPickerState, {}, {
    saveInput(node: any): void;
    weekDateRender({ current }: {
        current: any;
    }): JSX.Element;
    handleChange(value: moment.Moment | null): void;
    handleOpenChange(open: boolean): void;
    clearSelection(e: MouseEvent): void;
    focus(): void;
    blur(): void;
    renderFooter(...args: any[]): JSX.Element;
}, {
    methods: {
        setState(state: {}, callback: any): void;
        __emit(...args: any[]): void;
    };
}, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    onFocus: (...args: any[]) => any;
    onBlur: (...args: any[]) => any;
    onChange: (...args: any[]) => any;
    onMouseenter: (...args: any[]) => any;
    onMouseleave: (...args: any[]) => any;
    prefixCls: string;
    align: {
        [key: string]: any;
    };
    name: string;
    placeholder: string;
    transitionName: string;
    dropdownClassName: string;
    popupStyle: {
        [key: string]: any;
    };
    inputPrefixCls: string;
    onOpenChange: (...args: any[]) => any;
    tagPrefixCls: string;
    localeCode: string;
    getCalendarContainer: (...args: any[]) => any;
    disabledDate: (...args: any[]) => any;
    pickerClass: string;
    pickerInputClass: string;
    valueFormat: string;
} & {
    locale?: any;
    size?: "default" | "small" | "large";
    open?: boolean;
    disabled?: boolean;
    value?: import("./props").PickerValue;
    autofocus?: boolean;
    tabindex?: import("../_util/type").Key;
    defaultValue?: import("./props").PickerValue;
    allowClear?: boolean;
    suffixIcon?: any;
    showToday?: boolean;
    defaultPickerValue?: import("./props").PickerValue;
    timePicker?: any;
    renderExtraFooter?: any;
    format?: any;
    dateRender?: any;
    inputReadOnly?: boolean;
}>, {
    onFocus: (...args: any[]) => any;
    onBlur: (...args: any[]) => any;
    onChange: (...args: any[]) => any;
    onMouseenter: (...args: any[]) => any;
    onMouseleave: (...args: any[]) => any;
    prefixCls: string;
    align: {
        [key: string]: any;
    };
    name: string;
    placeholder: string;
    transitionName: string;
    dropdownClassName: string;
    popupStyle: {
        [key: string]: any;
    };
    inputPrefixCls: string;
    onOpenChange: (...args: any[]) => any;
    tagPrefixCls: string;
    localeCode: string;
    getCalendarContainer: (...args: any[]) => any;
    disabledDate: (...args: any[]) => any;
    pickerClass: string;
    pickerInputClass: string;
    valueFormat: string;
}>;
export default _default;

==> ant-design-vue-2.1.3.jar: META-INF/resources/webjars/ant-design-vue/2.1.3/lib/date-picker/WeekPicker.d.ts <==
import moment from 'moment';
interface WeekPickerState {
    _open?: boolean;
    _value?: moment.Moment | null;
}
declare const _default: import("vue").DefineComponent<{
    placeholder: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    value: {
        type: import("vue").PropType<import("./props").PickerValue>;
    };
    defaultValue: {
        type: import("vue").PropType<import("./props").PickerValue>;
    };
    defaultPickerValue: {
        type: import("vue").PropType<import("./props").PickerValue>;
    };
    renderExtraFooter: import("vue-types").VueTypeValidableDef<any>;
    onChange: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    name: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    transitionName: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    inputPrefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    format: import("vue-types").VueTypeDef<any>;
    disabled: import("vue-types").VueTypeValidableDef<boolean>;
    allowClear: import("vue-types").VueTypeValidableDef<boolean>;
    suffixIcon: import("vue-types").VueTypeValidableDef<any>;
    popupStyle: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    };
    dropdownClassName: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    locale: import("vue-types").VueTypeValidableDef<any>;
    localeCode: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    size: import("vue-types").VueTypeDef<"default" | "small" | "large">;
    getCalendarContainer: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    open: import("vue-types").VueTypeValidableDef<boolean>;
    disabledDate: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    showToday: import("vue-types").VueTypeValidableDef<boolean>;
    dateRender: import("vue-types").VueTypeValidableDef<any>;
    pickerClass: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    pickerInputClass: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    timePicker: import("vue-types").VueTypeValidableDef<any>;
    autofocus: import("vue-types").VueTypeValidableDef<boolean>;
    tagPrefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    tabindex: import("vue-types").VueTypeDef<string | number>;
    align: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    } & {
        default: () => {
            [key: string]: any;
        };
    };
    inputReadOnly: import("vue-types").VueTypeValidableDef<boolean>;
    valueFormat: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    onOpenChange: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    onFocus: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    onBlur: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    onMouseenter: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    onMouseleave: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
}, {
    configProvider: import("../config-provider").ConfigConsumerProps;
    prevState: WeekPickerState;
    input: any;
    sPrefixCls: any;
}, WeekPickerState, {}, {
    saveInput(node: any): void;
    weekDateRender({ current }: {
        current: any;
    }): JSX.Element;
    handleChange(value: moment.Moment | null): void;
    handleOpenChange(open: boolean): void;
    clearSelection(e: MouseEvent): void;
    focus(): void;
    blur(): void;
    renderFooter(...args: any[]): JSX.Element;
}, {
    methods: {
        setState(state: {}, callback: any): void;
        __emit(...args: any[]): void;
    };
}, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    onFocus: (...args: any[]) => any;
    onBlur: (...args: any[]) => any;
    onChange: (...args: any[]) => any;
    onMouseenter: (...args: any[]) => any;
    onMouseleave: (...args: any[]) => any;
    prefixCls: string;
    align: {
        [key: string]: any;
    };
    name: string;
    placeholder: string;
    transitionName: string;
    dropdownClassName: string;
    popupStyle: {
        [key: string]: any;
    };
    onOpenChange: (...args: any[]) => any;
    inputPrefixCls: string;
    tagPrefixCls: string;
    localeCode: string;
    getCalendarContainer: (...args: any[]) => any;
    disabledDate: (...args: any[]) => any;
    pickerClass: string;
    pickerInputClass: string;
    valueFormat: string;
} & {
    value?: import("./props").PickerValue;
    locale?: any;
    size?: "default" | "small" | "large";
    open?: boolean;
    disabled?: boolean;
    autofocus?: boolean;
    tabindex?: string | number;
    defaultValue?: import("./props").PickerValue;
    allowClear?: boolean;
    suffixIcon?: any;
    showToday?: boolean;
    defaultPickerValue?: import("./props").PickerValue;
    timePicker?: any;
    renderExtraFooter?: any;
    format?: any;
    dateRender?: any;
    inputReadOnly?: boolean;
}>, {
    onFocus: (...args: any[]) => any;
    onBlur: (...args: any[]) => any;
    onChange: (...args: any[]) => any;
    onMouseenter: (...args: any[]) => any;
    onMouseleave: (...args: any[]) => any;
    prefixCls: string;
    align: {
        [key: string]: any;
    };
    name: string;
    placeholder: string;
    transitionName: string;
    dropdownClassName: string;
    popupStyle: {
        [key: string]: any;
    };
    onOpenChange: (...args: any[]) => any;
    inputPrefixCls: string;
    tagPrefixCls: string;
    localeCode: string;
    getCalendarContainer: (...args: any[]) => any;
    disabledDate: (...args: any[]) => any;
    pickerClass: string;
    pickerInputClass: string;
    valueFormat: string;
}>;
export default _default;
